package com.liquidnet.service.platform.controller.goblin.code;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.excel.exception.ExcelDataConvertException;
import com.liquidnet.commons.lang.util.CollectionUtil;
import com.liquidnet.service.goblin.dto.vo.GoblinNftExCodeFetchExcelVo;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.List;

@Slf4j
public class CodeDataListener extends AnalysisEventListener<GoblinNftExCodeFetchExcelVo> {

    // 返回的数据集合
    List<String> phones = new ArrayList<>();

    @Override
    public void invoke(GoblinNftExCodeFetchExcelVo fetchExcel, AnalysisContext analysisContext) {
        phones.add(fetchExcel.getPhone());
    }

    /**
     * 在转换异常 获取其他异常下会调用本接口。抛出异常则停止读取。如果这里不抛出异常则 继续读取下一行。
     *
     * @param exception
     * @param context
     * @throws Exception
     */
    @Override
    public void onException(Exception exception, AnalysisContext context) {
        log.error("解析失败，但是继续解析下一行:{}", exception.getMessage());
        // 如果是某一个单元格的转换异常 能获取到具体行号
        // 如果要获取头的信息 配合invokeHeadMap使用
        if (exception instanceof ExcelDataConvertException) {
            ExcelDataConvertException excelDataConvertException = (ExcelDataConvertException)exception;
            log.error("第{}行，第{}列解析异常", excelDataConvertException.getRowIndex(),
                    excelDataConvertException.getColumnIndex());
        }
    }

    /**
     * 所有数据解析完成了 都会来调用
     *
     * @param analysisContext
     */
    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {

    }

    /**
     * 返回数据
     * @return
     */
    public List<String> getData(){
        return phones;
    }

    /**
     * 设置读取的数据集合
     *
     * @param phones 设置读取的数据集合
     **/
    public void setDatas(List<String> phones) {
        this.phones = phones;
    }


}

